@@ -3,9 +3,14 @@ import click
 import numpy as np
 from random import randint
 import cv2
-import os
 
-from .commons import OptionEatAll
+try:
+    from yaml import CSafeLoader as YAMLSafeLoader
+except ImportError:
+    from yaml import SafeLoader as YAMLSafeLoader
+from yaml import load as yaml_load
+from .commons import OptionEatAll, load_samples
+from ..parser import dsdl_parse
 
 
 @click.command()
@@ -18,26 +23,35 @@ from .commons import OptionEatAll
 @click.option("-v", "--visualize", is_flag=True, help="whether to visualize the sample selected")
 @click.option("-f", "--fields", cls=OptionEatAll, type=str, help="the task to visualize")
 @click.option("-t", "--task", type=str, help="the task to visualize")
-def view(dsdl_yaml, config, location, num, random, visualize, fields, task):
-
-    dsdl_py = os.path.splitext(dsdl_yaml)[0] + ".py"
-    with open(dsdl_py, encoding='utf-8') as dsdl_file:
-        exec(dsdl_file.read(), {})
-
+@click.option("-p", "--position", type=str, required=False, help='the directory of dsdl define file')
+def view(dsdl_yaml, config, location, num, random, visualize, fields, task, position):
+    with open(dsdl_yaml, "r") as f:
+        dsdl_info = yaml_load(f, Loader=YAMLSafeLoader)['data']
+        sample_type = dsdl_info['sample-type']
+        sample_path = dsdl_info["sample-path"]
+        if sample_path == "local":
+            samples = dsdl_info['samples']
+        else:
+            samples = load_samples(dsdl_yaml, sample_path)
+    if position:
+        dsdl_py = dsdl_parse(dsdl_yaml, position)
+    else:
+        dsdl_py = dsdl_parse(dsdl_yaml)
+    exec(dsdl_py, {})
     config_dic = {}
     with open(config, encoding='utf-8') as config_file:
         exec(config_file.read(), config_dic)
     location_config = config_dic["local" if location == "local" else "ali_oss"]
+    dataset = Dataset(samples, sample_type, location_config)
 
-    dataset = Dataset(dsdl_yaml, location_config)
     palette = {}
     if task:
         assert task in ["detection",
                         "segmentation"], "invalid task, you can only choose in ['detection', 'segmentation']"
         if task == "detection":
-            fields = ["image", "bool", "label", "bbox", "polygon"]
+            fields = ["image", "label", "bbox", "polygon", "attributes"]
         else:
-            fields = ["image", "bool", "label"]
+            fields = ["image", "label", "attributes"]
     else:
 
         if fields is None:
@@ -46,7 +60,7 @@ def view(dsdl_yaml, config, location, num, random, visualize, fields, task):
             local_dic = {}
             exec(f"f = list({fields})", {}, local_dic)
             fields = local_dic['f']
-        fields = list(set(fields + ["image", "bool"]))
+        fields = list(set(fields + ["image", "attributes"]))
     fields = [_.lower() for _ in fields]
 
     num = min(num, len(dataset))
