@@ -11,7 +11,8 @@ from .special import (
     TimeField,
 )
 from .unstructure import ImageField
-from .registry import registry
+from .registry import STRUCT, CLASSDOMAIN, LABEL
+from .class_domain import ClassDomain, Label
 
 __all__ = [
     "Struct",
@@ -29,5 +30,9 @@ __all__ = [
     "PolygonField",
     "DateField",
     "TimeField",
-    "registry",
+    "STRUCT",
+    "CLASSDOMAIN",
+    "ClassDomain",
+    "LABEL",
+    "Label",
 ]
